//#include "unistd.h"

TH2D *histos[3][7];
TH2D *histos3s[7];
TH2D *hall;


void plotlut()
{
  double t0[7]     =  {  0,   0,    0,    0.1,   0.5,   0.5,   0.5  };
  double dt0[7]    =  {  0,   0,    0,    0.1,   0.1,   0.5,   0.5  };
  double ped[7]    =  {  0,   0,    0,    0,     0,     0,     0    };
  double dped[7]   =  {  0,   0.1,  0.5,  0.0,   0.1,   0.0,   0.5  };
  int samples[3]   =  {  3, 6, 8  };
  char hname[256];
  
  for( int j=0; j < 7; j++)
    {
      //     histos3s[7];
      for( int i=0; i <3; i++ )
	{	  
	  sprintf(hname, "N%dt0%0.1fdt0%0.1fped%0.2fdped%0.1f", samples[i], t0[j], dt0[j], ped[j], dped[j] );
	  histos[i][j] = new TH2D( hname, hname, 200, 0, 10, 100, 0, 1 );
	}
    }

  hall = new TH2D( "hall", "hall", 200, 0, 10, 100, 0, 1 );
  char filename[256];

  for(int i=0; i < 7; i++)
    {
      int check = 0;
      sprintf(filename, "ltu-emcal-t0%0.1f-dt%0.1f-ped%0.1f-dped%0.1f.root", t0[i], dt0[i], ped[i], dped[i]);
      TFile *f = new TFile(filename, "read");

      if(f == 0)
	{
	  cout << "ERROR, file: " << filename << "  NOT FOUND !!" << endl;
	  continue;
	}
      
      TIter next(f->GetListOfKeys());
      TKey *key;
      
      while ((key=(TKey*)next())) 
	{
	  TH1D *h = f->Get( key->GetName() );
	  int sindex =  Name2Samples( key->GetName() );  
	    
	  if(sindex >=0 )
	    {
	      histos[sindex][i]->Fill(  h->GetMean(),    h->GetRMS()/ h->GetMean() );
	      hall->Fill(  h->GetMean(),   h->GetRMS()/ h->GetMean()  );
	      cout << " h->GetRMS()/ h->GetMean() = " <<  h->GetRMS()/ h->GetMean() << endl;
	      cout << "  h->GetMean() =  " <<  h->GetMean() << endl;
	      //	  cout << "INFO; sindex = "<< sindex << endl; 
	    }
	  else
	    {
	      // cout << "WARNING; sindex = "<< sindex << endl;
	    }
	}
      
      f->Close();
      delete f;
    }

  Fit();
  Plot();
  WriteFiles();
}


int Name2Samples(const char*  txt)
{
  if(strlen (txt) == 24 )
    {
      return 2;
    }
  if(strlen (txt) == 18 )
    {
      return 1;
    }
   if(strlen (txt) == 11 )
    {
      return 0;
    }
   return -1;
}


void Plot()
{
  TCanvas *c2 = new TCanvas("c2","Amplitude resolution",600,400);
  
  histos[0][0]->GetFunction("f00")->SetLineColor(kRed);
  histos[0][0]->GetFunction("f00")->SetFillColor(kRed);
  histos[0][0]->GetFunction("f00")->SetMarkerColor(kRed);
  histos[0][1]->GetFunction("f01")->SetLineColor(kBlue);
  histos[0][2]->GetFunction("f02")->SetLineColor(kGreen);
  histos[0][3]->GetFunction("f03")->SetLineColor(kRed);
  histos[0][4]->GetFunction("f04")->SetLineColor(kBlue);
  histos[0][5]->GetFunction("f05")->SetLineColor(kGreen);
  histos[0][6]->GetFunction("f06")->SetLineColor(kRed);
  
  histos[0][0]->Draw();
  histos[0][1]->Draw("same");
  histos[0][2]->Draw("same");
  histos[0][3]->Draw("same");
  histos[0][4]->Draw("same");
  histos[0][5]->Draw("same");
  histos[0][6]->Draw("same");
 
  leg = new TLegend(0.4,0.6,0.89,0.89); 
  leg->AddEntry(f00,"Theory 0","L");
  leg->AddEntry(f01,"Theory 1","L");
  leg->AddEntry(f02,"Theory 2","L");
  leg->AddEntry(f03,"Theory 3","L");
  leg->AddEntry(f04,"Theory 4","L");
  leg->AddEntry(f05,"Theory 5","L");
  leg->AddEntry(f06,"Theory 6","L");
  leg->SetHeader("Title");
  leg->Draw();
  
  c2->Draw();

}


void Fit()
{
  // TF1 *f1 = new TF1("f1","[0]/x",0.5, 5 );
  for(int i=0; i < 3; i++)
    {
      for( int j=0; j < 7; j++)
	{
	  char name[256];
	  sprintf(name,"f%d%d", i, j);
	  TF1 *f1 = new TF1(name,"[0]/x",0.5, 5 );  
	  cout << endl << endl <<   histos[i][j]->GetName() << endl;
	  histos[i][j]->Fit(f1, "RQ"); 
	}
    }
}


void WriteFiles()
{
  TFile *f = new TFile("lut-res.root", "recreate");
  for(int i=0; i < 3; i++)
    {
      for( int j=0; j < 7; j++)
	{
	  histos[i][j]->Write();
	}
    }
  
  hall->Write();
  f->Close();
  delete f;
}







